def window_minimize(driver: object) -> None:
    driver.minimize_window()  # type: ignore
